"use client";
import { useActionState, useEffect, useState } from "react";
import { addWine } from "~/server/actions/addWine";
import { getProducers } from "~/server/actions/allProducers";

async function fetchProducers() {
  const producers = await getProducers();
  return producers;
}

type ProducersData = {
  id: string;
  name: string;
  createdAt: Date;
  country: string;
  region: string;
  email: string;
}[];

export default function CreateWine() {
  const [formState, formAction] = useActionState(addWine, {
    message: "",
    errors: undefined,
    fieldValues: {
      name: "",
      producer: "",
    },
  });
  const [producers, setProducers] = useState<ProducersData>([]);
  useEffect(() => {
    async function loadProducers() {
      const producersData = await fetchProducers();
      setProducers(producersData);
    }
    loadProducers();
  }, []);
  return (
    <div className="container flex flex-col gap-4">
      <form action={formAction}>
        <input className="border-2" type="text" name="name" />
        <select name="producer">
          {producers.map((producer, i) => (
            <option key={i} value={producer.id}>
              {producer.name}
            </option>
          ))}
        </select>
        <button type="submit">Add wine</button>
      </form>
      {JSON.stringify(formState)}
    </div>
  );
}
